@@ -1,6 +1,12 @@
+# -*- coding: utf8 -*-
+
+try:
+    from ..utils.data_loader import read_mat_file, read_csv_file
+except:
+    from utils.data_loader import read_mat_file, read_csv_file
+
 import platform
 import cv2
-from utils.data_loader import read_mat_file, read_csv_file
 from scipy.io import savemat
 import tkinter as tk
 from tkinter import filedialog
@@ -541,8 +547,21 @@ def get_file_name_from_path(path):
     return path
 
 
-def run_application(video_path_, data_path_, v_width=640):
+def get_file_path(root_, initial_dir ='./'):
+
+    video_path = filedialog.askopenfilename(initialdir=initial_dir, title="Select the video file", parent=root_)
+    data_path = filedialog.askopenfilename(initialdir=initial_dir, title="Select the csv or mat file",
+                                           filetypes=[("CSV file", ".csv"),
+                                                       ("Matlab file", ".mat")], parent=root_)
+    return video_path, data_path
+
+
+def run_annotator(video_path_, data_path_, v_width=640):
     root = tk.Tk()
+
+    if video_path_ == "" or data_path_ == "":
+        video_path_, data_path_ = get_file_path(root)
+
     if video_path_ is "" or data_path_ is "":
         root.quit()
         root.destroy()
@@ -566,13 +585,4 @@ if __name__ == '__main__':
     parser.add_argument('--data_path', type=str, default="", help="Data file path(csv or mat) for labeling")
     args = parser.parse_args()
 
-    if args.video_path == "" or args.data_path == "":
-        video_path = filedialog.askopenfilename(initialdir='./', title="Select the video file")
-        data_path = filedialog.askopenfilename(initialdir='./', title="Select the csv or mat file",
-                                               filetypes=[("CSV file", ".csv"),
-                                                          ("Matlab file", ".mat")])
-    else:
-        video_path = args.video_path
-        data_path = args.data_path
-
-    run_application(video_path, data_path, v_width=args.vw)
+    run_annotator(args.video_path, args.data_path, v_width=args.vw)
