@@ -15,10 +15,11 @@ class HDF5Generator:
 
         labels = f[label_name][()]
         unique_labels = np.unique(labels)
-        hist = np.array([labels[labels == i].shape[0] for i in unique_labels])
 
+        self.class_histogram = np.array([labels[labels == i].shape[0] for i in unique_labels])
         self.n_class = unique_labels.shape[0]
-        self.class_weight = (1 / hist) * labels.shape[0] / self.n_class
+        c_weight = (1 / self.class_histogram) * labels.shape[0] / self.n_class
+        self.class_weight = {i: c_weight[i] for i in enumerate(c_weight)}
 
         if verbose > 0:
             print("=+*"*20)
